/*
 * PS2_Controller.h
 *
 *  Created on: 2015-02-08
 *      Author: Nelson Stoik
 *      Last Modififed: 2015-02-28
 */

#ifndef PS2_CONTROLLER_H_
#define PS2_CONTROLLER_H_

#include <stdio.h>
#include "includes.h"
#include "string.h"
#include "altera_up_avalon_ps2.h"
#include "altera_up_avalon_ps2_regs.h"
#include "altera_up_ps2_keyboard.h"


#define PS2_END_CONDITION					"ENTER"		/*the end condition to break up the input*/
#define PS2_MESSAGE_LENGTH					64			/*the max length a message can be*/

#define PS2_LAST_SCANNED_MUTEX_PRIORITY		10			/*priority required for last_scanned_mutex*/
#define PS2_INPUT_MUTEX_PRIORITY			11			/*priority required for input_mutex*/

/******************************************Public Functions************************************************/

/*
 * sets all variables to their starting values and starts the ps2 monitoring
 * task. call once before starting the main program
 */
void ps2_initialisation();

/*
 * clears all stored input from the ps2 controller
 */
void clear_input();

/*
 * enables the task to scan for data from ps2 device.
 * NOTE: scanning is enabled by default after ps2_initialisation is run
 */
void enable_scanning();

/*
 * disables the task from scanning for data from the ps2 device
 */
void disable_scanning();


/*
 * a task that polls the ps2 controller for available input. Is paused by
 * calling disable_scanning() and resumed by calling enable_scanning()
 */
void input_monitoring_task(void* pdata);

/*
 * read the codes from the ps2 controller and convert them to ascii
 * RETURNS:
 * 			DECODE_BAD: 			bad break code
 * 			READ_BAD:				bad read from ps2
 * 			READ_AND_DECODE_GOOD:	good read and decode
 */
int read_and_decode(char *decoded_string);

#endif /* PS2_CONTROLLER_H_ */

